#!/usr/bin/env python3
# encoding: utf-8

from . import _init_mimetypes # type: ignore
